@@ -14,7 +14,7 @@ package MCE::Core::Validation;
 use strict;
 use warnings;
 
-our $VERSION = '1.868';
+our $VERSION = '1.877';
 
 ## Items below are folded into MCE.
 
@@ -347,7 +347,7 @@ sub _parse_max_workers {
       $_ncpu_ul = $_ncpu = MCE::Util::get_ncpu();
       $_ncpu_ul = 8 if ($_ncpu_ul > 8);
 
-      if ($1 && $2) {
+      if (defined($1) && defined($2)) {
          local $@; $_max_workers = eval "int($_ncpu_ul $1 $2 + 0.5)"; ## no critic
          $_max_workers = 1 if (!$_max_workers || $_max_workers < 1);
          $_max_workers = $_ncpu if ($_max_workers > $_ncpu);
@@ -356,6 +356,13 @@ sub _parse_max_workers {
          $_max_workers = $_ncpu_ul;
       }
    }
+   elsif ($_max_workers =~ /^([0-9.]+)%$/) {
+      my $_percent = $1 / 100;
+      my $_ncpu = MCE::Util::get_ncpu();
+
+      $_max_workers = int($_ncpu * $_percent + 0.5);
+      $_max_workers = 1 if ($_max_workers < 1);
+   }
 
    return $_max_workers;
 }
@@ -391,7 +398,7 @@ MCE::Core::Validation - Core validation methods for Many-Core Engine
 
 =head1 VERSION
 
-This document describes MCE::Core::Validation version 1.868
+This document describes MCE::Core::Validation version 1.877
 
 =head1 DESCRIPTION
 
